@@ -14,12 +14,14 @@ WSDLS = {
         '2': 'https://ws2.responsys.net/webservices/wsdl/ResponsysWS_Level1.wsdl',
         '5': 'https://ws5.responsys.net/webservices/wsdl/ResponsysWS_Level1.wsdl',
         'rtm4': 'https://rtm4.responsys.net/tmws/services/TriggeredMessageWS?wsdl',
+        'rtm4b': 'https://rtm4b.responsys.net/tmws/services/TriggeredMessageWS?wsdl',
 }
 
 ENDPOINTS = {
         '2': 'https://ws2.responsys.net/webservices/services/ResponsysWSService',
         '5': 'https://ws5.responsys.net/webservices/services/ResponsysWSService',
         'rtm4': 'http://rtm4.responsys.net:80/tmws/services/TriggeredMessageWS',
+        'rtm4b': 'http://rtm4b.responsys.net:80/tmws/services/TriggeredMessageWS',
 }
 
 def retry(func):
@@ -81,14 +83,22 @@ class Interact(object):
             self.exec_rc()
 
     def exec_rc(self):
+        class Config(object):
+            pass
+        c = Config()
+        d = {}
         rc_path = os.path.join(
             os.getenv("HOME"), ".interact", "rc.py")
         if os.path.isfile(rc_path):
-            execfile(rc_path)
+            execfile(rc_path, d)
+        for attr, val in d.items():
+            setattr(c, attr, val)
+        self.config = c
+        return c
 
     def config_creds(self, username, password, pod, config_path=None):
         self.pod = str(pod)
-        assert self.pod in {'2', '5', 'rtm4'}, 'Pod should be 2 or 5'
+        assert self.pod in ENDPOINTS.keys(), 'Pod should be 2 or 5'
         if (
             username is None and 
             password is None and 
